# Le Secret

This is a TUI re-implementation of my freshman year project [The Secret](https://github.com/jerry871002/OOP-Final-Project) (it was 2018 by the way...🫣), an image steganography tool to hide secrets in plain sight.

## Installation

```
pip install lesecret
```

## Get Started

Start the TUI-based application with the following command:

```
lesecret
```

The rest is pretty self-explanatory, just play around and you will know how to use it 😆
